@@ -107,6 +107,10 @@ class FormaDePagamento(models.FormaPagamento, Plugavel):
             forma_pagamento["ativo_para_a_conta"] = self.pagamento_configuracao_ativo
             forma_pagamento["configurado"] = self.configurado is not None
             if plano_indice:
+                try:
+                    plano_indice = int(plano_indice)
+                except ValueError:
+                    plano_indice = 0
                 forma_pagamento["habilitado_na_loja"] = forma_pagamento["configurado"] and self.ativo and self.pagamento_configuracao_ativo and self.plano_indice <= plano_indice
             forma_pagamento["bancos_ativos_na_conta"] = self.bancos_ativos_na_conta
         if soh_habilitados and "habilitado_na_loja" in forma_pagamento and not forma_pagamento["habilitado_na_loja"]:
@@ -134,7 +138,7 @@ class FormaDePagamentoConfiguracao(models.FormaPagamentoConfiguracao, Plugavel):
             self._forma_de_pagamento = None
         if self._forma_de_pagamento is None:
             try:
-                self._forma_de_pagamento = FormaDePagamento.configuracoes_ativas(self.conta_id, pagamento_id=self.forma_pagamento_id)[0].to_dict()
+                self._forma_de_pagamento = FormaDePagamento.configuracoes_ativas(self.conta_id, pagamento_id=self.forma_pagamento_id)[0].to_dict(com_configuracao=True)
             except IndexError:
                 self._forma_de_pagamento = {}
         return self._forma_de_pagamento
