@@ -19,12 +19,14 @@ class Enviar(object):
             self.pedido_numero = self.pedido.numero
         self.dados = dados
         self.configuracao_pagamento = configuracao_pagamento
+        self.passo_atual = None
+        self.processa_resposta = False
 
     @property
     def formatador(self):
         return Formatador
 
-    def gerar_dados_de_envio(self):
+    def gerar_dados_de_envio(self, passo=None):
         return self.dados
 
     def obter_situacao_do_pedido(self, status_requisicao):
@@ -32,6 +34,10 @@ class Enviar(object):
             return SituacaoPedido.SITUACAO_PEDIDO_PAGO
         return SituacaoPedido.SITUACAO_PEDIDO_CANCELADO
 
+    @property
+    def valores_de_pagamento(self):
+        return None
+
     #FIXME: rever isso ao refatorar o sistema de pedido
     @property
     def valor_envio(self):
@@ -65,7 +71,7 @@ class EnviarPedido(Plugavel):
         self._requisicao = None
 
     def processar_resposta(self, resposta=None):
-        if getattr(self.requisicao, "processa_resposta", False):
+        if self.requisicao.processa_resposta:
             return self.requisicao.processar_resposta(resposta)
         return {"data": resposta.content, "status": resposta.status_code, "reenviar": False}
 
@@ -78,9 +84,9 @@ class EnviarPedido(Plugavel):
                 raise PluginNaoEncontrado(u"O meio de pagamento '{}' não possui a classe requisicao.EnviarPedido.".format(self.meio_pagamento))
         return self._requisicao
 
-    def post(self, segunda_tentativa=False):
+    def post(self, segunda_tentativa=False, passo=None):
         conexao = Conexao(self.meio_pagamento, self.configuracao_pagamento, self.requisicao, TipoConexao.envio, self.processar_resposta)
-        return conexao.post(segunda_tentativa)
+        return conexao.post(segunda_tentativa, passo)
 
     def enviar(self):
         if not self.configuracao_pagamento:
@@ -95,13 +101,18 @@ class EnviarPedido(Plugavel):
             resultado = self.post(segunda_tentativa=True)
         if resultado["status"] == 201 or resultado["status"] == 200:
             if self.requisicao.deve_gravar_dados_de_pagamento:
-                self.grava_identificacao_de_pagamento(resultado["identificador"])
+                identificador_id = resultado.get("identificador", None)
+                self.grava_dados_de_pagamento(identificador_id=identificador_id, valores=self.requisicao.valores_de_pagamento)
             situacao_do_pedido = self.requisicao.obter_situacao_do_pedido(resultado["status"])
             if situacao_do_pedido:
                 notificador.envia_alteracao_de_situacao_de_pedido(self.pedido.numero, situacao_do_pedido, self.pedido.conta_id)
         return resultado
 
-    def grava_identificacao_de_pagamento(self, identificacao):
+    def grava_dados_de_pagamento(self, identificador_id=None, valores=None):
         pedido_pagamento = self.pedido.pedido_pagamentos.get(pagamento=self.pedido.pagamento)
-        pedido_pagamento.identificador_id = identificacao
+        if valores:
+            for chave in valores.keys():
+                setattr(pedido_pagamento, chave, valores[chave])
+        else:
+            pedido_pagamento.identificador_id = identificador_id
         pedido_pagamento.save()
