@@ -36,7 +36,7 @@ class RegistroBase(object):
         raise NotImplementedError
 
     @property
-    def grava_identificador(self):
+    def deve_gravar_dados_de_pagamento(self):
         return False
 
     @property
@@ -118,7 +118,7 @@ class RegistrarPagamento(Plugavel):
         resultado = {}
         if self.registrador.obter_dados_do_gateway:
             self.registrador.dados.update(self.obtem_dados_do_gateway())
-        if self.registrador.grava_identificador:
+        if self.registrador.deve_gravar_dados_de_pagamento:
             self.grava_dados_de_pagamento(valores=self.registrador.valores_de_pagamento)
         if self.registrador.alterar_situacao:
             if self.achou_registro:
